@@ -399,10 +399,10 @@ c----       include '../../Zcode.h'
        integer ia, iz, np
        record /ptcl/ pj, a(*)
 
-       real*4 am, ga, tau, ich
-       integer ibar, k1, k2
-       common/abltisC/am(110),ga(110),tau(110),ich(110),
-     * ibar(110),k1(110),k2(110)
+c       real*4 am, ga, tau
+c       integer*2 ich,ibar,k1,k2
+c       common/abltisC/am(110),ga(110),tau(110),ich(110),
+c     * ibar(110),k1(110),k2(110)
        
        real*4 cxr, cyr, czr, elr, plr, tv
        integer ir, itr
