@@ -12,8 +12,8 @@ c         by putting  Es = 0.
      +, HeavyG2massN, HeavyG2symbol, HowGeomag, HowIntNuc, IncreaseXsec
      +, KEminObs2, Knockon, Kpicns, Kpilog, LpmBremEmin, LpmPairEmin
      +, LundPara, MagBrem, MagBremEmin, MagChgDist, MagD, MagE, MagN
-     +, MagPair, MagPairEmin, MaxComptonE, MaxPhotoE, Mudirp, MulLow
-     +, NoOfSites2, OffsetHeight, PathLimit, PrevEventNo, PtAvFrag
-     +, PtAvNonInteNuc, RatioToE0, RecoilKineMinE, Reverse, SeedFileDev
-     +, SucInt, SucPw, TempDev, TraceDev, Truncc, Truncn, Truncx
-     +, UpsilonMin, X0
+     +, MagPair, MagPairEmin, MaxComptonE, MaxPhotoE, Moliere, Mudirp
+     +, MulLow, NoOfSites2, OffsetHeight, PathLimit, PrevEventNo
+     +, PtAvFrag, PtAvNonInteNuc, RatioToE0, RecoilKineMinE, Reverse
+     +, SeedFileDev, SucInt, SucPw, TempDev, TraceDev, Truncc, Truncn
+     +, Truncx, UpsilonMin, X0
