@@ -138,11 +138,14 @@ c          1 dimensional case.
 
 
 #include  "Ztrack.h"
+#include  "Ztrackp.h"
+#include  "Zincidentv.h"
+
 
       integer n
       record /track/ aTrack
       record /ptcl/ pw(n)
-
+      real*8 temp, p
   
       integer i
       do i =  n, 1, -1          ! move leading ptcl last
@@ -155,9 +158,24 @@ c          1 dimensional case.
          aTrack.p.subcode = pw(i).subcode
          aTrack.p.charge = pw(i).charge
 #endif
-         call cresetMom(aTrack)
-         call cgetZenith(aTrack, aTrack.vec.coszenith)
-         call cpush(aTrack)
+c            see if angle of particle is larger than a lmit
+         call cscalerProd(aTrack.p.fm.p, DcAtObsXyz, temp)
+         call cpxyzp(aTrack.p.fm, p)
+         if(p .gt. 0.) then
+            temp = temp/p
+         else
+            temp = 1.
+         endif
+         if(temp .gt. BackAngLimit)  then
+c              only take some limitted angle particles
+c            call cresetMom(aTrack)  which is
+            aTrack.p.fm.p(1) = p * aTrack.vec.w.r(1)
+            aTrack.p.fm.p(2) = p * aTrack.vec.w.r(2)
+            aTrack.p.fm.p(3) = p * aTrack.vec.w.r(3)
+
+            call cgetZenith(aTrack, aTrack.vec.coszenith)
+            call cpush(aTrack)
+         endif
       enddo
       end
 
