@@ -1,6 +1,6 @@
 c          print an observation site information
 c
-      subroutine cprObsSite(aSite)
+      subroutine cprObsSite(io, aSite)
       implicit none
 #include "Zmagfield.h"
 #include "Zcoord.h"
@@ -9,25 +9,26 @@ c
 #include "Zobs.h"
 #include "Zobsp.h"
 #include "Zobsv.h"
-
+      integer io ! input. dev. no.
       record /site/ aSite
       
-      write(*, *)sngl(aSite.pos.depth*0.1),
+      write(io, *)sngl(aSite.pos.depth*0.1),
      * sngl(aSite.pos.height), 
      * sngl(aSite.pos.radiallen/1000.),
      * aSite.pos.xyz.r(1), aSite.pos.xyz.r(2), aSite.pos.xyz.r(3)
       end
 c    *********************************print header
-      subroutine cprObsSiteHd
+      subroutine cprObsSiteHd(io)
 c    **************************************
-      write(*, *)
+      integer io ! inpu.t dev. no.
+      write(io, *)
      * ' depth (gr/cm2)  Height(m)  Distance to E-center(km)'//
      * '   x,y,z in XYZ system(m)'
       end
 c 
 c          print an observation site information
 c
-      subroutine cprASObsSite(aSite)
+      subroutine cprASObsSite(io, aSite)
       implicit none
 #include "Zmagfield.h"
 #include "Zcoord.h"
@@ -36,19 +37,20 @@ c
 #include "Zobs.h"
 #include "Zobsp.h"
 #include "Zobsv.h"
-
+      integer io ! input . output dev. no.
       record /assite/ aSite
       
-      write(*, *)sngl(aSite.pos.depth*0.1),
+      write(io, *)sngl(aSite.pos.depth*0.1),
      * sngl(aSite.pos.height), 
      * sngl(aSite.pos.radiallen/1000.),
      * sngl(aSite.mu), 
      * aSite.pos.xyz.r(1), aSite.pos.xyz.r(2), aSite.pos.xyz.r(3)
       end
 c    *********************************print header
-      subroutine cprASObsSiteHd
+      subroutine cprASObsSiteHd(io)
 c    **************************************
-      write(*, *)
+      integer io ! input.
+      write(io, *)
      * ' depth (gr/cm2)    Height(m)   Distance to E-center(km)'//
      * ' Molere Unit(m)     x,y,z in XYZ system (m)'
       end
