@@ -21,6 +21,7 @@ c      ***  do until no more ptcl in stack
       do while (.true.)
 c           get one particle from stack
          call cpop(TrackBefMove, moreptcl)
+
          if(moreptcl .eq. 0) goto 100   !  exit
          call rndsw(jold, 1)            !  specify 1st generator.
          call cifDead(TrackBefMove, icon)  ! generator may be switched to 2
@@ -87,6 +88,7 @@ c                next is for DEBUG
       character*70 msg
 cc      integer icon
 
+
          call cfixMedia   ! 
 c           sample interaction length.  The path may
 c           be truncated to a shorter one than really sampled.
@@ -100,6 +102,8 @@ c           path in the above process may be again truncated to
 c           a shorter one. This happens, for example, if ptcl energy
 c           is low.  Path inf is reset in IntInfArray.
          call ctruncPath
+
+
 #if DEBUG == 1
          call checkstat('after ctruncPath')
 #endif
@@ -107,6 +111,7 @@ c           is low.  Path inf is reset in IntInfArray.
 c           compute path end inf. including scattering and
 c           mag. deflection.  Path end inf is set in MovedTrack
          call ccompPathEnd
+
 #if DEBUG == 1
          call checkstat('after ccompPathEnd')
 #endif
@@ -203,6 +208,7 @@ c              nothing to do.
             write(msg, *) ' movestat=',MoveStat,' invalid'
            call cerrorMsg(msg, 0)
          endif   
+
       end
 #if DEBUG > 0
       subroutine checkstat(str)
@@ -250,9 +256,13 @@ c-------------------------------------------------------
       integer icon
       real*8 u
 
-      TargetMassN = 14.5
-      TargetAtomicN = 7.25
+c       weight average  ! weight ratio: 75.53, 23.14, 1.28 %
+      TargetMassN = 14.7
+      TargetAtomicN = 7.36
+      TargetZ2 = 55.7  ! <Z^2>
+      
       call rndc(u)
+c            volume ratio
       if(u .lt. .78) then
 c          nitrogen
          TargetNucleonNo = 14
@@ -284,11 +294,7 @@ c               reset mag field.
             x = TrackBefMove.pos.xyz.r(1)
             y = TrackBefMove.pos.xyz.r(2)
             z = TrackBefMove.pos.xyz.r(3)
-c//////////
-c            write(*, *) sngl(Mag.x), sngl(Mag.y), sngl(Mag.z),
-c     *      sngl(TrackBefMove.pos.height), 
-c     *      sngl(sqrt(Mag.x**2+ Mag.y**2 + Mag.z**2))
-c //////////
+
          endif
       else
          Mag = MagfieldXYZ
@@ -384,22 +390,24 @@ c              convert kg/m2 into length
             jcut = 0
          endif
          if(leng .lt. minlen) then
-               if(jcut .ne. 0) then
-                  MoveStat = Truncated
-               else
-                  jcut = 0
-                  MoveStat = ToInteract
-               endif
-               ProcessNo = i
-               IntInfArray(i).length = leng
-               minlen = leng
+            if(jcut .ne. 0) then
+               MoveStat = Truncated
+            else
+               jcut = 0
+               MoveStat = ToInteract
+            endif
+            ProcessNo = i
+            IntInfArray(i).length = leng
+            minlen = leng
          endif
       enddo
+
       if(IntInfArray(ProcessNo).decay .or. jcut .ne. 0) then
          IntInfArray(ProcessNo).thickness = clen2thick(h, 
      *      TrackBefMove.vec.coszenith, 
      *      IntInfArray(ProcessNo).length )
       endif
+
       end
 c     ***********************
 c          truncate a path of the particle, if the path
